/*******************************************************************************
* File Name: cen.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_cen_H) /* Pins cen_H */
#define CY_PINS_cen_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "cen_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 cen__PORT == 15 && ((cen__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    cen_Write(uint8 value);
void    cen_SetDriveMode(uint8 mode);
uint8   cen_ReadDataReg(void);
uint8   cen_Read(void);
void    cen_SetInterruptMode(uint16 position, uint16 mode);
uint8   cen_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the cen_SetDriveMode() function.
     *  @{
     */
        #define cen_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define cen_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define cen_DM_RES_UP          PIN_DM_RES_UP
        #define cen_DM_RES_DWN         PIN_DM_RES_DWN
        #define cen_DM_OD_LO           PIN_DM_OD_LO
        #define cen_DM_OD_HI           PIN_DM_OD_HI
        #define cen_DM_STRONG          PIN_DM_STRONG
        #define cen_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define cen_MASK               cen__MASK
#define cen_SHIFT              cen__SHIFT
#define cen_WIDTH              1u

/* Interrupt constants */
#if defined(cen__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in cen_SetInterruptMode() function.
     *  @{
     */
        #define cen_INTR_NONE      (uint16)(0x0000u)
        #define cen_INTR_RISING    (uint16)(0x0001u)
        #define cen_INTR_FALLING   (uint16)(0x0002u)
        #define cen_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define cen_INTR_MASK      (0x01u) 
#endif /* (cen__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define cen_PS                     (* (reg8 *) cen__PS)
/* Data Register */
#define cen_DR                     (* (reg8 *) cen__DR)
/* Port Number */
#define cen_PRT_NUM                (* (reg8 *) cen__PRT) 
/* Connect to Analog Globals */                                                  
#define cen_AG                     (* (reg8 *) cen__AG)                       
/* Analog MUX bux enable */
#define cen_AMUX                   (* (reg8 *) cen__AMUX) 
/* Bidirectional Enable */                                                        
#define cen_BIE                    (* (reg8 *) cen__BIE)
/* Bit-mask for Aliased Register Access */
#define cen_BIT_MASK               (* (reg8 *) cen__BIT_MASK)
/* Bypass Enable */
#define cen_BYP                    (* (reg8 *) cen__BYP)
/* Port wide control signals */                                                   
#define cen_CTL                    (* (reg8 *) cen__CTL)
/* Drive Modes */
#define cen_DM0                    (* (reg8 *) cen__DM0) 
#define cen_DM1                    (* (reg8 *) cen__DM1)
#define cen_DM2                    (* (reg8 *) cen__DM2) 
/* Input Buffer Disable Override */
#define cen_INP_DIS                (* (reg8 *) cen__INP_DIS)
/* LCD Common or Segment Drive */
#define cen_LCD_COM_SEG            (* (reg8 *) cen__LCD_COM_SEG)
/* Enable Segment LCD */
#define cen_LCD_EN                 (* (reg8 *) cen__LCD_EN)
/* Slew Rate Control */
#define cen_SLW                    (* (reg8 *) cen__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define cen_PRTDSI__CAPS_SEL       (* (reg8 *) cen__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define cen_PRTDSI__DBL_SYNC_IN    (* (reg8 *) cen__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define cen_PRTDSI__OE_SEL0        (* (reg8 *) cen__PRTDSI__OE_SEL0) 
#define cen_PRTDSI__OE_SEL1        (* (reg8 *) cen__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define cen_PRTDSI__OUT_SEL0       (* (reg8 *) cen__PRTDSI__OUT_SEL0) 
#define cen_PRTDSI__OUT_SEL1       (* (reg8 *) cen__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define cen_PRTDSI__SYNC_OUT       (* (reg8 *) cen__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(cen__SIO_CFG)
    #define cen_SIO_HYST_EN        (* (reg8 *) cen__SIO_HYST_EN)
    #define cen_SIO_REG_HIFREQ     (* (reg8 *) cen__SIO_REG_HIFREQ)
    #define cen_SIO_CFG            (* (reg8 *) cen__SIO_CFG)
    #define cen_SIO_DIFF           (* (reg8 *) cen__SIO_DIFF)
#endif /* (cen__SIO_CFG) */

/* Interrupt Registers */
#if defined(cen__INTSTAT)
    #define cen_INTSTAT            (* (reg8 *) cen__INTSTAT)
    #define cen_SNAP               (* (reg8 *) cen__SNAP)
    
	#define cen_0_INTTYPE_REG 		(* (reg8 *) cen__0__INTTYPE)
#endif /* (cen__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_cen_H */


/* [] END OF FILE */
