/*******************************************************************************
* File Name: CAM_PK.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_CAM_PK_H) /* Pins CAM_PK_H */
#define CY_PINS_CAM_PK_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "CAM_PK_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 CAM_PK__PORT == 15 && ((CAM_PK__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    CAM_PK_Write(uint8 value);
void    CAM_PK_SetDriveMode(uint8 mode);
uint8   CAM_PK_ReadDataReg(void);
uint8   CAM_PK_Read(void);
void    CAM_PK_SetInterruptMode(uint16 position, uint16 mode);
uint8   CAM_PK_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the CAM_PK_SetDriveMode() function.
     *  @{
     */
        #define CAM_PK_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define CAM_PK_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define CAM_PK_DM_RES_UP          PIN_DM_RES_UP
        #define CAM_PK_DM_RES_DWN         PIN_DM_RES_DWN
        #define CAM_PK_DM_OD_LO           PIN_DM_OD_LO
        #define CAM_PK_DM_OD_HI           PIN_DM_OD_HI
        #define CAM_PK_DM_STRONG          PIN_DM_STRONG
        #define CAM_PK_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define CAM_PK_MASK               CAM_PK__MASK
#define CAM_PK_SHIFT              CAM_PK__SHIFT
#define CAM_PK_WIDTH              1u

/* Interrupt constants */
#if defined(CAM_PK__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in CAM_PK_SetInterruptMode() function.
     *  @{
     */
        #define CAM_PK_INTR_NONE      (uint16)(0x0000u)
        #define CAM_PK_INTR_RISING    (uint16)(0x0001u)
        #define CAM_PK_INTR_FALLING   (uint16)(0x0002u)
        #define CAM_PK_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define CAM_PK_INTR_MASK      (0x01u) 
#endif /* (CAM_PK__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define CAM_PK_PS                     (* (reg8 *) CAM_PK__PS)
/* Data Register */
#define CAM_PK_DR                     (* (reg8 *) CAM_PK__DR)
/* Port Number */
#define CAM_PK_PRT_NUM                (* (reg8 *) CAM_PK__PRT) 
/* Connect to Analog Globals */                                                  
#define CAM_PK_AG                     (* (reg8 *) CAM_PK__AG)                       
/* Analog MUX bux enable */
#define CAM_PK_AMUX                   (* (reg8 *) CAM_PK__AMUX) 
/* Bidirectional Enable */                                                        
#define CAM_PK_BIE                    (* (reg8 *) CAM_PK__BIE)
/* Bit-mask for Aliased Register Access */
#define CAM_PK_BIT_MASK               (* (reg8 *) CAM_PK__BIT_MASK)
/* Bypass Enable */
#define CAM_PK_BYP                    (* (reg8 *) CAM_PK__BYP)
/* Port wide control signals */                                                   
#define CAM_PK_CTL                    (* (reg8 *) CAM_PK__CTL)
/* Drive Modes */
#define CAM_PK_DM0                    (* (reg8 *) CAM_PK__DM0) 
#define CAM_PK_DM1                    (* (reg8 *) CAM_PK__DM1)
#define CAM_PK_DM2                    (* (reg8 *) CAM_PK__DM2) 
/* Input Buffer Disable Override */
#define CAM_PK_INP_DIS                (* (reg8 *) CAM_PK__INP_DIS)
/* LCD Common or Segment Drive */
#define CAM_PK_LCD_COM_SEG            (* (reg8 *) CAM_PK__LCD_COM_SEG)
/* Enable Segment LCD */
#define CAM_PK_LCD_EN                 (* (reg8 *) CAM_PK__LCD_EN)
/* Slew Rate Control */
#define CAM_PK_SLW                    (* (reg8 *) CAM_PK__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define CAM_PK_PRTDSI__CAPS_SEL       (* (reg8 *) CAM_PK__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define CAM_PK_PRTDSI__DBL_SYNC_IN    (* (reg8 *) CAM_PK__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define CAM_PK_PRTDSI__OE_SEL0        (* (reg8 *) CAM_PK__PRTDSI__OE_SEL0) 
#define CAM_PK_PRTDSI__OE_SEL1        (* (reg8 *) CAM_PK__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define CAM_PK_PRTDSI__OUT_SEL0       (* (reg8 *) CAM_PK__PRTDSI__OUT_SEL0) 
#define CAM_PK_PRTDSI__OUT_SEL1       (* (reg8 *) CAM_PK__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define CAM_PK_PRTDSI__SYNC_OUT       (* (reg8 *) CAM_PK__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(CAM_PK__SIO_CFG)
    #define CAM_PK_SIO_HYST_EN        (* (reg8 *) CAM_PK__SIO_HYST_EN)
    #define CAM_PK_SIO_REG_HIFREQ     (* (reg8 *) CAM_PK__SIO_REG_HIFREQ)
    #define CAM_PK_SIO_CFG            (* (reg8 *) CAM_PK__SIO_CFG)
    #define CAM_PK_SIO_DIFF           (* (reg8 *) CAM_PK__SIO_DIFF)
#endif /* (CAM_PK__SIO_CFG) */

/* Interrupt Registers */
#if defined(CAM_PK__INTSTAT)
    #define CAM_PK_INTSTAT            (* (reg8 *) CAM_PK__INTSTAT)
    #define CAM_PK_SNAP               (* (reg8 *) CAM_PK__SNAP)
    
	#define CAM_PK_0_INTTYPE_REG 		(* (reg8 *) CAM_PK__0__INTTYPE)
#endif /* (CAM_PK__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_CAM_PK_H */


/* [] END OF FILE */
