/*******************************************************************************
* File Name: oen.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_oen_H) /* Pins oen_H */
#define CY_PINS_oen_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "oen_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 oen__PORT == 15 && ((oen__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    oen_Write(uint8 value);
void    oen_SetDriveMode(uint8 mode);
uint8   oen_ReadDataReg(void);
uint8   oen_Read(void);
void    oen_SetInterruptMode(uint16 position, uint16 mode);
uint8   oen_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the oen_SetDriveMode() function.
     *  @{
     */
        #define oen_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define oen_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define oen_DM_RES_UP          PIN_DM_RES_UP
        #define oen_DM_RES_DWN         PIN_DM_RES_DWN
        #define oen_DM_OD_LO           PIN_DM_OD_LO
        #define oen_DM_OD_HI           PIN_DM_OD_HI
        #define oen_DM_STRONG          PIN_DM_STRONG
        #define oen_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define oen_MASK               oen__MASK
#define oen_SHIFT              oen__SHIFT
#define oen_WIDTH              1u

/* Interrupt constants */
#if defined(oen__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in oen_SetInterruptMode() function.
     *  @{
     */
        #define oen_INTR_NONE      (uint16)(0x0000u)
        #define oen_INTR_RISING    (uint16)(0x0001u)
        #define oen_INTR_FALLING   (uint16)(0x0002u)
        #define oen_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define oen_INTR_MASK      (0x01u) 
#endif /* (oen__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define oen_PS                     (* (reg8 *) oen__PS)
/* Data Register */
#define oen_DR                     (* (reg8 *) oen__DR)
/* Port Number */
#define oen_PRT_NUM                (* (reg8 *) oen__PRT) 
/* Connect to Analog Globals */                                                  
#define oen_AG                     (* (reg8 *) oen__AG)                       
/* Analog MUX bux enable */
#define oen_AMUX                   (* (reg8 *) oen__AMUX) 
/* Bidirectional Enable */                                                        
#define oen_BIE                    (* (reg8 *) oen__BIE)
/* Bit-mask for Aliased Register Access */
#define oen_BIT_MASK               (* (reg8 *) oen__BIT_MASK)
/* Bypass Enable */
#define oen_BYP                    (* (reg8 *) oen__BYP)
/* Port wide control signals */                                                   
#define oen_CTL                    (* (reg8 *) oen__CTL)
/* Drive Modes */
#define oen_DM0                    (* (reg8 *) oen__DM0) 
#define oen_DM1                    (* (reg8 *) oen__DM1)
#define oen_DM2                    (* (reg8 *) oen__DM2) 
/* Input Buffer Disable Override */
#define oen_INP_DIS                (* (reg8 *) oen__INP_DIS)
/* LCD Common or Segment Drive */
#define oen_LCD_COM_SEG            (* (reg8 *) oen__LCD_COM_SEG)
/* Enable Segment LCD */
#define oen_LCD_EN                 (* (reg8 *) oen__LCD_EN)
/* Slew Rate Control */
#define oen_SLW                    (* (reg8 *) oen__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define oen_PRTDSI__CAPS_SEL       (* (reg8 *) oen__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define oen_PRTDSI__DBL_SYNC_IN    (* (reg8 *) oen__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define oen_PRTDSI__OE_SEL0        (* (reg8 *) oen__PRTDSI__OE_SEL0) 
#define oen_PRTDSI__OE_SEL1        (* (reg8 *) oen__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define oen_PRTDSI__OUT_SEL0       (* (reg8 *) oen__PRTDSI__OUT_SEL0) 
#define oen_PRTDSI__OUT_SEL1       (* (reg8 *) oen__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define oen_PRTDSI__SYNC_OUT       (* (reg8 *) oen__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(oen__SIO_CFG)
    #define oen_SIO_HYST_EN        (* (reg8 *) oen__SIO_HYST_EN)
    #define oen_SIO_REG_HIFREQ     (* (reg8 *) oen__SIO_REG_HIFREQ)
    #define oen_SIO_CFG            (* (reg8 *) oen__SIO_CFG)
    #define oen_SIO_DIFF           (* (reg8 *) oen__SIO_DIFF)
#endif /* (oen__SIO_CFG) */

/* Interrupt Registers */
#if defined(oen__INTSTAT)
    #define oen_INTSTAT            (* (reg8 *) oen__INTSTAT)
    #define oen_SNAP               (* (reg8 *) oen__SNAP)
    
	#define oen_0_INTTYPE_REG 		(* (reg8 *) oen__0__INTTYPE)
#endif /* (oen__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_oen_H */


/* [] END OF FILE */
