#include <kernel.h>
#include <t_syslog.h>
#include <t_stdlib.h>
#include "syssvc/serial.h"
#include "syssvc/syslog.h"
#include "kernel_cfg.h"

#include "rapiro.h"
#include "cpp_Serial.h"
#include "sw.h"

#include "apds.h"

/* Direction definitions */
enum {
  DIR_NONE,
  DIR_LEFT,
  DIR_RIGHT,
  DIR_UP,
  DIR_DOWN,
  DIR_NEAR,
  DIR_FAR,
  DIR_ALL
};

#define F(p) p

#define UP      3
#define DOWN    4
#define RIGHT   2
#define LEFT    1

#define START   0
#define GAME    1
#define JUDGE   2

unsigned int Gesture, mode;
unsigned long int next =1;  //For rand()
unsigned long int rnd =1;   //For rand()
unsigned int pass_flg = 0;  // At first, Gesture sensor detects NONE
unsigned int state = START;
unsigned int onepass = 0;
volatile unsigned int sw2_val, sw3_val;


//Prototype
unsigned int rand(void);
void srand(unsigned int seed);
void Gesture_catch(unsigned int Gesture);
void Rapi_actition(unsigned int mode);

void task_gesture(intptr_t exinf)
{
	apds_led_off();

	// Initialize APDS-9960 (configure I2C and initial values)
	if(apds_init()){
		serial_println(F("APDS-9960 initialization complete"));
	}else{
		serial_println(F("Something went wrong during APDS-9960 init!"));
	}

	// Start running the APDS-9960 gesture sensor engine
	if(apds_enableGestureSensor(true)){
		serial_println(F("Gesture sensor is now running"));
	}else{
		serial_println(F("Something went wrong during gesture sensor init!"));
	}

    srand(5);
	apds_led_on();

    serial_println("START");

LOOP:    
    
    while(1){
        sw2_val = sw2_read();
        if(!(sw2_val)){ break;}
    }    

	while(1)
	{      
        switch(state){
            case START:
                state = GAME;
                snd_dtq(DTQ_EYE, (intptr_t)0);
                serial2_println("#M7"); //Stop Stright Both hands Tate                
                dly_tsk(3000);
                while(1){
                    sw3_val = sw3_read();
                        if(sw3_val){
                            break;
                        }
                        else{
                            state = START;
                            goto LOOP;
                        }
                }                
                // Rapi action standby
                next = rand();
        		mode = rand()%4 + 1;
                serial3_println("call.wav");
                dly_tsk(2500);
                break;
            case GAME:
        		if(apds_int_read() != 1 && apds_isGestureAvailable() == 1) // APDS_INT OFF
        		{
     				Gesture = apds_readGesture();
                    Gesture_catch(Gesture);                  
					if(Gesture==DIR_UP || Gesture==DIR_DOWN || Gesture==DIR_LEFT || Gesture==DIR_RIGHT){
                        Rapi_actition(mode);
                        state = JUDGE;
                        dly_tsk(3000);
				    }
                    else{
                            serial3_println("retry.wav");
                            state = START;
                            dly_tsk(2500);                            
                    }
        		}
                else{
                    state = GAME;
                }
                break;
            case JUDGE:
                    if(Gesture==(mode)){
                        snd_dtq(DTQ_EYE, (intptr_t)3);
                        serial3_println("lost.wav");
                        state = START;                    
                        dly_tsk(2500);                        
                    }
                    else{
                        if(Gesture==DIR_UP || Gesture==DIR_DOWN || Gesture==DIR_LEFT || Gesture==DIR_RIGHT){
                            snd_dtq(DTQ_EYE, (intptr_t)1);
                            serial3_println("win.wav");
                            state = START;                        
                            dly_tsk(2500);             
                        }
                        else{}
                    }
                break;
            default:
                   break;
        }
		dly_tsk(1);
	}

	syslog(LOG_NOTICE, "Sample program ends.");
	SVC_PERROR(ext_ker());
	assert(0);
}

unsigned int rand(void)
{
    next = next * 1103515245 + 12345;
    return (unsigned int)(next/65536) % 32768;
}

void srand(unsigned int seed)
{
    next = seed;
}

void Gesture_catch(unsigned int Gesture){
	switch(Gesture){
		case DIR_UP:
			serial_println("UP");
			break;
		case DIR_DOWN:
			serial_println("DOWN");
			break;
		case DIR_LEFT:
			serial_println("LEFT");
			break;
		case DIR_RIGHT:
			serial_println("RIGHT");
			break;
		case DIR_NEAR:
			serial_println("NEAR");
			break;
		case DIR_FAR:
			serial_println("FAR");
			break;
		default:
			serial_println("NONE");
	}
}

void Rapi_actition(unsigned int mode){
    switch(mode){ // mode:Rnd 0-3
	case UP:
	    serial2_println("#PS02A150T001"); //Up Right-Hand
//		serial3_println("ue.wav");
//		dly_tsk(3000);
//      snd_dtq(DTQ_EYE, (intptr_t)0);
		break;
	case DOWN:
        serial2_println("#PS05A150T001"); //Down Left-Hand
//      serial3_println("shita.wav");
//		dly_tsk(3000);
//      snd_dtq(DTQ_EYE, (intptr_t)1);
		break;
	case RIGHT:
        serial2_println("#PS00A170T001"); //Left Head
//      serial3_println("migi.wav");
//		dly_tsk(3000);
//      snd_dtq(DTQ_EYE, (intptr_t)2);
		break;
	case LEFT:
        serial2_println("#PS00A010T001"); //Right Head
//      serial3_println("hidari.wav");
//      snd_dtq(DTQ_EYE, (intptr_t)3);
//		dly_tsk(3000);
		break;
    }         
}