/*******************************************************************************
* File Name: LEDBL.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_LEDBL_H) /* Pins LEDBL_H */
#define CY_PINS_LEDBL_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "LEDBL_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 LEDBL__PORT == 15 && ((LEDBL__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    LEDBL_Write(uint8 value);
void    LEDBL_SetDriveMode(uint8 mode);
uint8   LEDBL_ReadDataReg(void);
uint8   LEDBL_Read(void);
void    LEDBL_SetInterruptMode(uint16 position, uint16 mode);
uint8   LEDBL_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the LEDBL_SetDriveMode() function.
     *  @{
     */
        #define LEDBL_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define LEDBL_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define LEDBL_DM_RES_UP          PIN_DM_RES_UP
        #define LEDBL_DM_RES_DWN         PIN_DM_RES_DWN
        #define LEDBL_DM_OD_LO           PIN_DM_OD_LO
        #define LEDBL_DM_OD_HI           PIN_DM_OD_HI
        #define LEDBL_DM_STRONG          PIN_DM_STRONG
        #define LEDBL_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define LEDBL_MASK               LEDBL__MASK
#define LEDBL_SHIFT              LEDBL__SHIFT
#define LEDBL_WIDTH              1u

/* Interrupt constants */
#if defined(LEDBL__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in LEDBL_SetInterruptMode() function.
     *  @{
     */
        #define LEDBL_INTR_NONE      (uint16)(0x0000u)
        #define LEDBL_INTR_RISING    (uint16)(0x0001u)
        #define LEDBL_INTR_FALLING   (uint16)(0x0002u)
        #define LEDBL_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define LEDBL_INTR_MASK      (0x01u) 
#endif /* (LEDBL__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define LEDBL_PS                     (* (reg8 *) LEDBL__PS)
/* Data Register */
#define LEDBL_DR                     (* (reg8 *) LEDBL__DR)
/* Port Number */
#define LEDBL_PRT_NUM                (* (reg8 *) LEDBL__PRT) 
/* Connect to Analog Globals */                                                  
#define LEDBL_AG                     (* (reg8 *) LEDBL__AG)                       
/* Analog MUX bux enable */
#define LEDBL_AMUX                   (* (reg8 *) LEDBL__AMUX) 
/* Bidirectional Enable */                                                        
#define LEDBL_BIE                    (* (reg8 *) LEDBL__BIE)
/* Bit-mask for Aliased Register Access */
#define LEDBL_BIT_MASK               (* (reg8 *) LEDBL__BIT_MASK)
/* Bypass Enable */
#define LEDBL_BYP                    (* (reg8 *) LEDBL__BYP)
/* Port wide control signals */                                                   
#define LEDBL_CTL                    (* (reg8 *) LEDBL__CTL)
/* Drive Modes */
#define LEDBL_DM0                    (* (reg8 *) LEDBL__DM0) 
#define LEDBL_DM1                    (* (reg8 *) LEDBL__DM1)
#define LEDBL_DM2                    (* (reg8 *) LEDBL__DM2) 
/* Input Buffer Disable Override */
#define LEDBL_INP_DIS                (* (reg8 *) LEDBL__INP_DIS)
/* LCD Common or Segment Drive */
#define LEDBL_LCD_COM_SEG            (* (reg8 *) LEDBL__LCD_COM_SEG)
/* Enable Segment LCD */
#define LEDBL_LCD_EN                 (* (reg8 *) LEDBL__LCD_EN)
/* Slew Rate Control */
#define LEDBL_SLW                    (* (reg8 *) LEDBL__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define LEDBL_PRTDSI__CAPS_SEL       (* (reg8 *) LEDBL__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define LEDBL_PRTDSI__DBL_SYNC_IN    (* (reg8 *) LEDBL__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define LEDBL_PRTDSI__OE_SEL0        (* (reg8 *) LEDBL__PRTDSI__OE_SEL0) 
#define LEDBL_PRTDSI__OE_SEL1        (* (reg8 *) LEDBL__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define LEDBL_PRTDSI__OUT_SEL0       (* (reg8 *) LEDBL__PRTDSI__OUT_SEL0) 
#define LEDBL_PRTDSI__OUT_SEL1       (* (reg8 *) LEDBL__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define LEDBL_PRTDSI__SYNC_OUT       (* (reg8 *) LEDBL__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(LEDBL__SIO_CFG)
    #define LEDBL_SIO_HYST_EN        (* (reg8 *) LEDBL__SIO_HYST_EN)
    #define LEDBL_SIO_REG_HIFREQ     (* (reg8 *) LEDBL__SIO_REG_HIFREQ)
    #define LEDBL_SIO_CFG            (* (reg8 *) LEDBL__SIO_CFG)
    #define LEDBL_SIO_DIFF           (* (reg8 *) LEDBL__SIO_DIFF)
#endif /* (LEDBL__SIO_CFG) */

/* Interrupt Registers */
#if defined(LEDBL__INTSTAT)
    #define LEDBL_INTSTAT            (* (reg8 *) LEDBL__INTSTAT)
    #define LEDBL_SNAP               (* (reg8 *) LEDBL__SNAP)
    
	#define LEDBL_0_INTTYPE_REG 		(* (reg8 *) LEDBL__0__INTTYPE)
#endif /* (LEDBL__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_LEDBL_H */


/* [] END OF FILE */
