/*******************************************************************************
* File Name: LEDGL.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_LEDGL_H) /* Pins LEDGL_H */
#define CY_PINS_LEDGL_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "LEDGL_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 LEDGL__PORT == 15 && ((LEDGL__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    LEDGL_Write(uint8 value);
void    LEDGL_SetDriveMode(uint8 mode);
uint8   LEDGL_ReadDataReg(void);
uint8   LEDGL_Read(void);
void    LEDGL_SetInterruptMode(uint16 position, uint16 mode);
uint8   LEDGL_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the LEDGL_SetDriveMode() function.
     *  @{
     */
        #define LEDGL_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define LEDGL_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define LEDGL_DM_RES_UP          PIN_DM_RES_UP
        #define LEDGL_DM_RES_DWN         PIN_DM_RES_DWN
        #define LEDGL_DM_OD_LO           PIN_DM_OD_LO
        #define LEDGL_DM_OD_HI           PIN_DM_OD_HI
        #define LEDGL_DM_STRONG          PIN_DM_STRONG
        #define LEDGL_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define LEDGL_MASK               LEDGL__MASK
#define LEDGL_SHIFT              LEDGL__SHIFT
#define LEDGL_WIDTH              1u

/* Interrupt constants */
#if defined(LEDGL__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in LEDGL_SetInterruptMode() function.
     *  @{
     */
        #define LEDGL_INTR_NONE      (uint16)(0x0000u)
        #define LEDGL_INTR_RISING    (uint16)(0x0001u)
        #define LEDGL_INTR_FALLING   (uint16)(0x0002u)
        #define LEDGL_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define LEDGL_INTR_MASK      (0x01u) 
#endif /* (LEDGL__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define LEDGL_PS                     (* (reg8 *) LEDGL__PS)
/* Data Register */
#define LEDGL_DR                     (* (reg8 *) LEDGL__DR)
/* Port Number */
#define LEDGL_PRT_NUM                (* (reg8 *) LEDGL__PRT) 
/* Connect to Analog Globals */                                                  
#define LEDGL_AG                     (* (reg8 *) LEDGL__AG)                       
/* Analog MUX bux enable */
#define LEDGL_AMUX                   (* (reg8 *) LEDGL__AMUX) 
/* Bidirectional Enable */                                                        
#define LEDGL_BIE                    (* (reg8 *) LEDGL__BIE)
/* Bit-mask for Aliased Register Access */
#define LEDGL_BIT_MASK               (* (reg8 *) LEDGL__BIT_MASK)
/* Bypass Enable */
#define LEDGL_BYP                    (* (reg8 *) LEDGL__BYP)
/* Port wide control signals */                                                   
#define LEDGL_CTL                    (* (reg8 *) LEDGL__CTL)
/* Drive Modes */
#define LEDGL_DM0                    (* (reg8 *) LEDGL__DM0) 
#define LEDGL_DM1                    (* (reg8 *) LEDGL__DM1)
#define LEDGL_DM2                    (* (reg8 *) LEDGL__DM2) 
/* Input Buffer Disable Override */
#define LEDGL_INP_DIS                (* (reg8 *) LEDGL__INP_DIS)
/* LCD Common or Segment Drive */
#define LEDGL_LCD_COM_SEG            (* (reg8 *) LEDGL__LCD_COM_SEG)
/* Enable Segment LCD */
#define LEDGL_LCD_EN                 (* (reg8 *) LEDGL__LCD_EN)
/* Slew Rate Control */
#define LEDGL_SLW                    (* (reg8 *) LEDGL__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define LEDGL_PRTDSI__CAPS_SEL       (* (reg8 *) LEDGL__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define LEDGL_PRTDSI__DBL_SYNC_IN    (* (reg8 *) LEDGL__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define LEDGL_PRTDSI__OE_SEL0        (* (reg8 *) LEDGL__PRTDSI__OE_SEL0) 
#define LEDGL_PRTDSI__OE_SEL1        (* (reg8 *) LEDGL__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define LEDGL_PRTDSI__OUT_SEL0       (* (reg8 *) LEDGL__PRTDSI__OUT_SEL0) 
#define LEDGL_PRTDSI__OUT_SEL1       (* (reg8 *) LEDGL__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define LEDGL_PRTDSI__SYNC_OUT       (* (reg8 *) LEDGL__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(LEDGL__SIO_CFG)
    #define LEDGL_SIO_HYST_EN        (* (reg8 *) LEDGL__SIO_HYST_EN)
    #define LEDGL_SIO_REG_HIFREQ     (* (reg8 *) LEDGL__SIO_REG_HIFREQ)
    #define LEDGL_SIO_CFG            (* (reg8 *) LEDGL__SIO_CFG)
    #define LEDGL_SIO_DIFF           (* (reg8 *) LEDGL__SIO_DIFF)
#endif /* (LEDGL__SIO_CFG) */

/* Interrupt Registers */
#if defined(LEDGL__INTSTAT)
    #define LEDGL_INTSTAT            (* (reg8 *) LEDGL__INTSTAT)
    #define LEDGL_SNAP               (* (reg8 *) LEDGL__SNAP)
    
	#define LEDGL_0_INTTYPE_REG 		(* (reg8 *) LEDGL__0__INTTYPE)
#endif /* (LEDGL__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_LEDGL_H */


/* [] END OF FILE */
