/*******************************************************************************
* File Name: LEDGR.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_LEDGR_H) /* Pins LEDGR_H */
#define CY_PINS_LEDGR_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "LEDGR_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 LEDGR__PORT == 15 && ((LEDGR__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    LEDGR_Write(uint8 value);
void    LEDGR_SetDriveMode(uint8 mode);
uint8   LEDGR_ReadDataReg(void);
uint8   LEDGR_Read(void);
void    LEDGR_SetInterruptMode(uint16 position, uint16 mode);
uint8   LEDGR_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the LEDGR_SetDriveMode() function.
     *  @{
     */
        #define LEDGR_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define LEDGR_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define LEDGR_DM_RES_UP          PIN_DM_RES_UP
        #define LEDGR_DM_RES_DWN         PIN_DM_RES_DWN
        #define LEDGR_DM_OD_LO           PIN_DM_OD_LO
        #define LEDGR_DM_OD_HI           PIN_DM_OD_HI
        #define LEDGR_DM_STRONG          PIN_DM_STRONG
        #define LEDGR_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define LEDGR_MASK               LEDGR__MASK
#define LEDGR_SHIFT              LEDGR__SHIFT
#define LEDGR_WIDTH              1u

/* Interrupt constants */
#if defined(LEDGR__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in LEDGR_SetInterruptMode() function.
     *  @{
     */
        #define LEDGR_INTR_NONE      (uint16)(0x0000u)
        #define LEDGR_INTR_RISING    (uint16)(0x0001u)
        #define LEDGR_INTR_FALLING   (uint16)(0x0002u)
        #define LEDGR_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define LEDGR_INTR_MASK      (0x01u) 
#endif /* (LEDGR__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define LEDGR_PS                     (* (reg8 *) LEDGR__PS)
/* Data Register */
#define LEDGR_DR                     (* (reg8 *) LEDGR__DR)
/* Port Number */
#define LEDGR_PRT_NUM                (* (reg8 *) LEDGR__PRT) 
/* Connect to Analog Globals */                                                  
#define LEDGR_AG                     (* (reg8 *) LEDGR__AG)                       
/* Analog MUX bux enable */
#define LEDGR_AMUX                   (* (reg8 *) LEDGR__AMUX) 
/* Bidirectional Enable */                                                        
#define LEDGR_BIE                    (* (reg8 *) LEDGR__BIE)
/* Bit-mask for Aliased Register Access */
#define LEDGR_BIT_MASK               (* (reg8 *) LEDGR__BIT_MASK)
/* Bypass Enable */
#define LEDGR_BYP                    (* (reg8 *) LEDGR__BYP)
/* Port wide control signals */                                                   
#define LEDGR_CTL                    (* (reg8 *) LEDGR__CTL)
/* Drive Modes */
#define LEDGR_DM0                    (* (reg8 *) LEDGR__DM0) 
#define LEDGR_DM1                    (* (reg8 *) LEDGR__DM1)
#define LEDGR_DM2                    (* (reg8 *) LEDGR__DM2) 
/* Input Buffer Disable Override */
#define LEDGR_INP_DIS                (* (reg8 *) LEDGR__INP_DIS)
/* LCD Common or Segment Drive */
#define LEDGR_LCD_COM_SEG            (* (reg8 *) LEDGR__LCD_COM_SEG)
/* Enable Segment LCD */
#define LEDGR_LCD_EN                 (* (reg8 *) LEDGR__LCD_EN)
/* Slew Rate Control */
#define LEDGR_SLW                    (* (reg8 *) LEDGR__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define LEDGR_PRTDSI__CAPS_SEL       (* (reg8 *) LEDGR__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define LEDGR_PRTDSI__DBL_SYNC_IN    (* (reg8 *) LEDGR__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define LEDGR_PRTDSI__OE_SEL0        (* (reg8 *) LEDGR__PRTDSI__OE_SEL0) 
#define LEDGR_PRTDSI__OE_SEL1        (* (reg8 *) LEDGR__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define LEDGR_PRTDSI__OUT_SEL0       (* (reg8 *) LEDGR__PRTDSI__OUT_SEL0) 
#define LEDGR_PRTDSI__OUT_SEL1       (* (reg8 *) LEDGR__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define LEDGR_PRTDSI__SYNC_OUT       (* (reg8 *) LEDGR__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(LEDGR__SIO_CFG)
    #define LEDGR_SIO_HYST_EN        (* (reg8 *) LEDGR__SIO_HYST_EN)
    #define LEDGR_SIO_REG_HIFREQ     (* (reg8 *) LEDGR__SIO_REG_HIFREQ)
    #define LEDGR_SIO_CFG            (* (reg8 *) LEDGR__SIO_CFG)
    #define LEDGR_SIO_DIFF           (* (reg8 *) LEDGR__SIO_DIFF)
#endif /* (LEDGR__SIO_CFG) */

/* Interrupt Registers */
#if defined(LEDGR__INTSTAT)
    #define LEDGR_INTSTAT            (* (reg8 *) LEDGR__INTSTAT)
    #define LEDGR_SNAP               (* (reg8 *) LEDGR__SNAP)
    
	#define LEDGR_0_INTTYPE_REG 		(* (reg8 *) LEDGR__0__INTTYPE)
#endif /* (LEDGR__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_LEDGR_H */


/* [] END OF FILE */
