/*******************************************************************************
* File Name: SPIM_ETH_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPIM_ETH_PVT.h"

static SPIM_ETH_BACKUP_STRUCT SPIM_ETH_backup =
{
    SPIM_ETH_DISABLED,
    SPIM_ETH_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPIM_ETH_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_ETH_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_ETH_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_ETH_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_ETH_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_ETH_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_ETH_Sleep(void) 
{
    /* Save components enable state */
    SPIM_ETH_backup.enableState = ((uint8) SPIM_ETH_IS_ENABLED);

    SPIM_ETH_Stop();
}


/*******************************************************************************
* Function Name: SPIM_ETH_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_ETH_backup - used when non-retention registers are restored.
*  SPIM_ETH_txBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_ETH_txBufferRead - modified every function call - resets to
*  zero.
*  SPIM_ETH_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_ETH_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_ETH_Wakeup(void) 
{
    #if(SPIM_ETH_RX_SOFTWARE_BUF_ENABLED)
        SPIM_ETH_rxBufferFull  = 0u;
        SPIM_ETH_rxBufferRead  = 0u;
        SPIM_ETH_rxBufferWrite = 0u;
    #endif /* (SPIM_ETH_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPIM_ETH_TX_SOFTWARE_BUF_ENABLED)
        SPIM_ETH_txBufferFull  = 0u;
        SPIM_ETH_txBufferRead  = 0u;
        SPIM_ETH_txBufferWrite = 0u;
    #endif /* (SPIM_ETH_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPIM_ETH_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPIM_ETH_backup.enableState)
    {
        SPIM_ETH_Enable();
    }
}


/* [] END OF FILE */
