/*******************************************************************************
* File Name: LEDBR.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_LEDBR_H) /* Pins LEDBR_H */
#define CY_PINS_LEDBR_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "LEDBR_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 LEDBR__PORT == 15 && ((LEDBR__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    LEDBR_Write(uint8 value);
void    LEDBR_SetDriveMode(uint8 mode);
uint8   LEDBR_ReadDataReg(void);
uint8   LEDBR_Read(void);
void    LEDBR_SetInterruptMode(uint16 position, uint16 mode);
uint8   LEDBR_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the LEDBR_SetDriveMode() function.
     *  @{
     */
        #define LEDBR_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define LEDBR_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define LEDBR_DM_RES_UP          PIN_DM_RES_UP
        #define LEDBR_DM_RES_DWN         PIN_DM_RES_DWN
        #define LEDBR_DM_OD_LO           PIN_DM_OD_LO
        #define LEDBR_DM_OD_HI           PIN_DM_OD_HI
        #define LEDBR_DM_STRONG          PIN_DM_STRONG
        #define LEDBR_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define LEDBR_MASK               LEDBR__MASK
#define LEDBR_SHIFT              LEDBR__SHIFT
#define LEDBR_WIDTH              1u

/* Interrupt constants */
#if defined(LEDBR__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in LEDBR_SetInterruptMode() function.
     *  @{
     */
        #define LEDBR_INTR_NONE      (uint16)(0x0000u)
        #define LEDBR_INTR_RISING    (uint16)(0x0001u)
        #define LEDBR_INTR_FALLING   (uint16)(0x0002u)
        #define LEDBR_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define LEDBR_INTR_MASK      (0x01u) 
#endif /* (LEDBR__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define LEDBR_PS                     (* (reg8 *) LEDBR__PS)
/* Data Register */
#define LEDBR_DR                     (* (reg8 *) LEDBR__DR)
/* Port Number */
#define LEDBR_PRT_NUM                (* (reg8 *) LEDBR__PRT) 
/* Connect to Analog Globals */                                                  
#define LEDBR_AG                     (* (reg8 *) LEDBR__AG)                       
/* Analog MUX bux enable */
#define LEDBR_AMUX                   (* (reg8 *) LEDBR__AMUX) 
/* Bidirectional Enable */                                                        
#define LEDBR_BIE                    (* (reg8 *) LEDBR__BIE)
/* Bit-mask for Aliased Register Access */
#define LEDBR_BIT_MASK               (* (reg8 *) LEDBR__BIT_MASK)
/* Bypass Enable */
#define LEDBR_BYP                    (* (reg8 *) LEDBR__BYP)
/* Port wide control signals */                                                   
#define LEDBR_CTL                    (* (reg8 *) LEDBR__CTL)
/* Drive Modes */
#define LEDBR_DM0                    (* (reg8 *) LEDBR__DM0) 
#define LEDBR_DM1                    (* (reg8 *) LEDBR__DM1)
#define LEDBR_DM2                    (* (reg8 *) LEDBR__DM2) 
/* Input Buffer Disable Override */
#define LEDBR_INP_DIS                (* (reg8 *) LEDBR__INP_DIS)
/* LCD Common or Segment Drive */
#define LEDBR_LCD_COM_SEG            (* (reg8 *) LEDBR__LCD_COM_SEG)
/* Enable Segment LCD */
#define LEDBR_LCD_EN                 (* (reg8 *) LEDBR__LCD_EN)
/* Slew Rate Control */
#define LEDBR_SLW                    (* (reg8 *) LEDBR__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define LEDBR_PRTDSI__CAPS_SEL       (* (reg8 *) LEDBR__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define LEDBR_PRTDSI__DBL_SYNC_IN    (* (reg8 *) LEDBR__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define LEDBR_PRTDSI__OE_SEL0        (* (reg8 *) LEDBR__PRTDSI__OE_SEL0) 
#define LEDBR_PRTDSI__OE_SEL1        (* (reg8 *) LEDBR__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define LEDBR_PRTDSI__OUT_SEL0       (* (reg8 *) LEDBR__PRTDSI__OUT_SEL0) 
#define LEDBR_PRTDSI__OUT_SEL1       (* (reg8 *) LEDBR__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define LEDBR_PRTDSI__SYNC_OUT       (* (reg8 *) LEDBR__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(LEDBR__SIO_CFG)
    #define LEDBR_SIO_HYST_EN        (* (reg8 *) LEDBR__SIO_HYST_EN)
    #define LEDBR_SIO_REG_HIFREQ     (* (reg8 *) LEDBR__SIO_REG_HIFREQ)
    #define LEDBR_SIO_CFG            (* (reg8 *) LEDBR__SIO_CFG)
    #define LEDBR_SIO_DIFF           (* (reg8 *) LEDBR__SIO_DIFF)
#endif /* (LEDBR__SIO_CFG) */

/* Interrupt Registers */
#if defined(LEDBR__INTSTAT)
    #define LEDBR_INTSTAT            (* (reg8 *) LEDBR__INTSTAT)
    #define LEDBR_SNAP               (* (reg8 *) LEDBR__SNAP)
    
	#define LEDBR_0_INTTYPE_REG 		(* (reg8 *) LEDBR__0__INTTYPE)
#endif /* (LEDBR__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_LEDBR_H */


/* [] END OF FILE */
