#include <stdarg.h>
#include <stdio.h>
#include <string.h>

#include <kernel.h>
#include <t_syslog.h>
#include <t_stdlib.h>
#include "syssvc/serial.h"
#include "syssvc/syslog.h"
#include "kernel_cfg.h"

#include "rapiro.h"
#include "cpp_if.h"
#include "cpp_Serial.h"

ER_UINT Serial::begin(ID portid)
{
	ER_UINT	ercd;
	id = portid;

	ercd = serial_opn_por(id);
	if (ercd < 0 && MERCD(ercd) != E_OBJ) {
		syslog(LOG_ERROR, "%s (%d) reported by `serial_opn_por'.",
									itron_strerror(ercd), SERCD(ercd));
	}
	SVC_PERROR(serial_ctl_por(id,
							(IOCTL_CRLF | IOCTL_FCSND | IOCTL_FCRCV)));

	return ercd;
}

ER_UINT Serial::begin(ID portid, uint_t ioctl)
{
	ER_UINT	ercd;
	id = portid;

	ercd = serial_opn_por(id);
	if (ercd < 0 && MERCD(ercd) != E_OBJ) {
		syslog(LOG_ERROR, "%s (%d) reported by `serial_opn_por'.",
									itron_strerror(ercd), SERCD(ercd));
	}
	SVC_PERROR(serial_ctl_por(id, ioctl));

	return ercd;
}

void Serial::print(const char *str)
{
	serial_wri_dat(id, str, strlen(str));
}

char Serial::ggetc()
{
	char c;

	serial_rea_dat(id, &c, 1);
	return c;
}

char* Serial::gets(char *buf, int len, int *size)
{
	char c;
	int n;

	for(n = 0; n < len - 1; n++)
	{
		serial_rea_dat(id, &c, 1);

		buf[n] = c;

		if('\n' == c)
		{
			n++;
			break;
		}
	}
	buf[n] = '\0';
	*size = n;

	return buf;
}

static Serial serial;
static Serial serial1;
static Serial serial2;
static Serial serial3;

ER_UINT serial_begin(ID portid)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX);
	ercd = serial.begin(portid);
	sig_sem(SEM_STX);
	return ercd;
}

ER_UINT serial_begin2(ID portid, uint_t ioctl)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX);
	ercd = serial.begin(portid, ioctl);
	sig_sem(SEM_STX);
	return ercd;
}

void serial_print(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	serial.print(buf);
	sig_sem(SEM_STX);
}

void serial_println(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	strcat(buf,"\n");
	serial.print(buf);
	sig_sem(SEM_STX);
}

char serial_getc(void)
{
	char c;

	wai_sem(SEM_SRX);
	c = serial.ggetc();
	sig_sem(SEM_SRX);
	return c;
}

char *serial_gets(char *buf, int len, int *size)
{
	wai_sem(SEM_SRX);
	serial.gets(buf, len, size);
	sig_sem(SEM_SRX);
	return buf;
}

ER_UINT serial1_begin(ID portid)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX1);
	ercd = serial1.begin(portid);
	sig_sem(SEM_STX1);
	return ercd;
}

ER_UINT serial1_begin2(ID portid, uint_t ioctl)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX1);
	ercd = serial1.begin(portid, ioctl);
	sig_sem(SEM_STX1);
	return ercd;
}

void serial1_print(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX1);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	serial1.print(buf);
	sig_sem(SEM_STX1);
}

void serial1_println(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX1);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	strcat(buf,"\n");
	serial1.print(buf);
	sig_sem(SEM_STX1);
}

char serial1_getc(void)
{
	char c;

	wai_sem(SEM_SRX1);
	c = serial1.ggetc();
	sig_sem(SEM_SRX1);
	return c;
}

char *serial1_gets(char *buf, int len, int *size)
{
	wai_sem(SEM_SRX1);
	serial1.gets(buf, len, size);
	sig_sem(SEM_SRX1);
	return buf;
}

ER_UINT serial2_begin(ID portid)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX2);
	ercd = serial2.begin(portid);
	sig_sem(SEM_STX2);
	return ercd;
}

ER_UINT serial2_begin2(ID portid, uint_t ioctl)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX2);
	ercd = serial2.begin(portid, ioctl);
	sig_sem(SEM_STX2);
	return ercd;
}

void serial2_print(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX2);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	serial2.print(buf);
	sig_sem(SEM_STX2);
}

void serial2_println(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX2);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	strcat(buf,"\n");
	serial2.print(buf);
	sig_sem(SEM_STX2);
}

char serial2_getc(void)
{
	char c;

	wai_sem(SEM_SRX2);
	c = serial2.ggetc();
	sig_sem(SEM_SRX2);
	return c;
}

char *serial2_gets(char *buf, int len, int *size)
{
	wai_sem(SEM_SRX2);
	serial2.gets(buf, len, size);
	sig_sem(SEM_SRX2);
	return buf;
}

ER_UINT serial3_begin(ID portid)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX3);
	ercd = serial3.begin(portid);
	sig_sem(SEM_STX3);
	return ercd;
}

ER_UINT serial3_begin2(ID portid, uint_t ioctl)
{
	ER_UINT	ercd;

	wai_sem(SEM_STX3);
	ercd = serial3.begin(portid, ioctl);
	sig_sem(SEM_STX3);
	return ercd;
}

void serial3_print(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX3);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	serial3.print(buf);
	sig_sem(SEM_STX3);
}

void serial3_println(const char *control, ...)
{
	char buf[128];
	va_list vargs;

	wai_sem(SEM_STX3);
	va_start(vargs, control);
	vsprintf(buf, control, vargs);
	va_end(vargs);

	strcat(buf,"\n");
	serial3.print(buf);
	sig_sem(SEM_STX3);
}

char serial3_getc(void)
{
	char c;

	wai_sem(SEM_SRX3);
	c = serial3.ggetc();
	sig_sem(SEM_SRX3);
	return c;
}

char *serial3_gets(char *buf, int len, int *size)
{
	wai_sem(SEM_SRX3);
	serial3.gets(buf, len, size);
	sig_sem(SEM_SRX3);
	return buf;
}
