typedef char int8_t;

extern "C" {
#include <string.h>
#include "WProgram.h"
#include "Adafruit_LEDBackpack.h"
#include "matrix.h"
}

static Adafruit_8x8matrix matrix_l = Adafruit_8x8matrix();
static Adafruit_8x8matrix matrix_r = Adafruit_8x8matrix();

static uint16_t displaybuffer[8]; 

static void drawPixel(int16_t x, int16_t y, uint16_t color)
{
#if 0
 // check rotation, move pixel around if necessary
  switch (getRotation()) {
  case 2:
    _swap_int16_t(x, y);
    x = 16 - x - 1;
    break;
  case 3:
    x = 16 - x - 1;
    y = 8 - y - 1;
    break;
  case 0:
    _swap_int16_t(x, y);
    y = 8 - y - 1;
    break;
  }
#endif
  /*
  Serial.print("("); Serial.print(x);
  Serial.print(","); Serial.print(y);
  Serial.println(")");
  */

  if ((y < 0) || (y >= 8)) return;
  if ((x < 0) || (x >= 16)) return;

  if (color) {
    displaybuffer[y] |= 1 << x;
  } else {
    displaybuffer[y] &= ~(1 << x);
  }
}

static
void l_drawBitmap(int16_t x, int16_t y, const uint8_t *bitmap, int16_t w, int16_t h, uint16_t color)
{
  int16_t i, j, byteWidth = (w + 7) / 8;
  uint8_t byte;

  for(j=0; j<h; j++) {
    for(i=0; i<w; i++) {
      if(i & 7) byte <<= 1;
      else      byte   = pgm_read_byte(bitmap + j * byteWidth + i / 8);
      if(byte & 0x80) drawPixel(x+i, y+j, color);
    }
  }
	memcpy(matrix_l.displaybuffer, displaybuffer, sizeof(displaybuffer));
}

static
void r_drawBitmap(int16_t x, int16_t y, const uint8_t *bitmap, int16_t w, int16_t h, uint16_t color)
{
  int16_t i, j, byteWidth = (w + 7) / 8;
  uint8_t byte;

  for(j=0; j<h; j++) {
    for(i=0; i<w; i++) {
      if(i & 7) byte <<= 1;
      else      byte   = pgm_read_byte(bitmap + j * byteWidth + i / 8);
      if(byte & 0x80) drawPixel(x+i, y+j, color);
    }
  }
	memcpy(matrix_r.displaybuffer, displaybuffer, sizeof(displaybuffer));
}

void matrix_l_begin(uint8_t _addr)
{
	matrix_l.begin(_addr); 
	return;
}

void matrix_r_begin(uint8_t _addr)
{
	matrix_r.begin(_addr); 
	return;
}

void matrix_l_clear(void)
{
	memset(displaybuffer, 0, sizeof(displaybuffer));
	matrix_l.clear();
	return;
}

void matrix_r_clear(void)
{
	memset(displaybuffer, 0, sizeof(displaybuffer));
	matrix_r.clear();
	return;
}

void matrix_l_drawBitmap(int16_t x, int16_t y, const uint8_t *bitmap, int16_t w, int16_t h, uint16_t color)
{
	l_drawBitmap(x, y, bitmap, w, h, color);
	return;
}

void matrix_r_drawBitmap(int16_t x, int16_t y, const uint8_t *bitmap, int16_t w, int16_t h, uint16_t color)
{
	r_drawBitmap(x, y, bitmap, w, h, color);
	return;
}

void matrix_l_writeDisplay(void)
{
	matrix_l.writeDisplay();
	return;
}

void matrix_r_writeDisplay(void)
{
	matrix_r.writeDisplay();
	return;
}
