 /**
 * Helloworld style, connect an ESP8266 to the IBM IoT Foundation
 * 
 * Author: Ant Elder
 * License: Apache License v2
 */
#include <ESP8266WiFi.h>
#include <PubSubClient.h> // https://github.com/knolleary/pubsubclient/releases/tag/v2.3

//-------- Customise these values -----------

#define DEFAULT_SSID "*****"
#define DEFAULT_PASS "*****"

const char* ssid = DEFAULT_SSID;
const char* password = DEFAULT_PASS;


#define ORG "*****"
#define DEVICE_TYPE "*****"
#define DEVICE_ID "*****"
#define TOKEN "*****"
//-------- Customise the above values --------

char server[] = ORG ".messaging.internetofthings.ibmcloud.com";
char topic[] = "iot-2/evt/status/fmt/json";
char authMethod[] = "use-token-auth";
char token[] = TOKEN;
char clientId[] = "d:" ORG ":" DEVICE_TYPE ":" DEVICE_ID;

WiFiClient wifiClient;
PubSubClient client(server, 1883, NULL, wifiClient);

void setup()
{
	Serial.begin(115200);
	Serial.println();

	Serial.print("Connecting to ");
	Serial.print(ssid);

	WiFi.begin(ssid, password);

	while(WiFi.status() != WL_CONNECTED)
	{
		delay(500);
		Serial.print(".");
	}
	Serial.println("");

	Serial.print("WiFi connected, IP address: "); Serial.println(WiFi.localIP());
}

int counter = 0;

void loop()
{
	if(!client.connected())
	{
		Serial.print("Reconnecting client to ");
		Serial.println(server);

		while(!!!client.connect(clientId, authMethod, token))
		{
			Serial.print(".");
			delay(500);
		}
		Serial.println();
	}

#if 1
	String payload = "{\"d\":{\"myName\":\"ESP8266.Test1\",\"counter\":";
	payload += counter;
	payload += "}}";

	Serial.print("Sending payload: ");
	Serial.println(payload);

	if(client.publish(topic, (char*) payload.c_str()))
	{
		Serial.println("Publish ok");
	}
	else
	{
		Serial.println("Publish failed");
	}

	++counter;
	delay(10000);
#else
	static char recbuf[1024] = "";
	static int p = 0;
	char rec;

	if(Serial.available())
	{
		while(1)
		{
			rec = Serial.read();
//			Serial.println(rec, HEX);

			if(0xff == rec)
			{
				break;
			}

			if(('\n' == rec)
			|| ('\r' == rec))
			{
				recbuf[p] = '\0';
				if(strlen(recbuf))
				{
					String payload = String(recbuf);

					Serial.print("Sending payload: ");
					Serial.println(payload);

					if(client.publish(topic, recbuf))
					{
						Serial.println("Publish ok");
					}
					else
					{
						Serial.println("Publish failed");
					}
				}
				p = 0;
			}
			else
			{
				recbuf[p++] = rec;
				recbuf[p] = '\0';
			}
		}

	}
#endif
}
